#!/usr/bin/perl
#
# Rotates jpeg images $AMOUNT degrees clockwise. Moves originals to
# <name>_orig.jpg. 
#
# Copyright Arto Ters <ajt@iki.fi> 1999-2000
#
# Version: 1.0
# Licence: GNU General Public License (version 2 or any later version)
#          http://www.gnu.org/copyleft/gpl.txt
#
# Latest version: http://www.iki.fi/ajt/software/thumbnailtools/
######################################################################
#
# Global defaults:
# 
$AMOUNT = 90;   # the amount to rotate (clockwise), can be adjusted 
                # with the command line option -a

$QUALITY = 75;  # output image quality, can be adjusted with the 
                # command line option -q
#
######################################################################

use Getopt::Std;

sub find_program {
    # Quick check if the given program can be found in the PATH
    # This will work only on Unix machines...
    my $program = shift;
    @system_dirs = split(':', $ENV{PATH});

    foreach (@system_dirs) {
	if (-x "$_/${program}") {
	    return 1;
	}
    }    
    # not found
    return 0;
}

# The main program
#
getopts('a:q:');

if (@ARGV) 
{   
    if ($opt_a != 0) {
	$AMOUNT = $opt_a;
    }
    if ($opt_q != 0) {
	$QUALITY = $opt_q;
    }

    # Check that the program convert can be executed:
    if (find_program("convert") == 0) {
	    print STDERR "Couldn't find the \"convert\" utility (part of the ImageMagick package).\n\n";
	    print STDERR "Please make sure that it can be found in the PATH and try again.\n"; 
	    exit(1);
    }

    my $image;
    foreach $image (@ARGV) 
    {
	if ($image =~ /(.*)\.jpg/)
	{
	    print "Processing image $image\n";	
	    my $basename = $1;
	    my $origname = "$basename" . "_orig.jpg";
	    
	    # Let's preserve the original, if it doesn't exist
	    if (-f $origname)
	    {
		print "$origname already exists, using that!\n";
	    }
	    else
	    {
		`mv $image $origname`;
	    }
	    
	    # Generate rotated image
	    `convert -rotate $AMOUNT -quality $QUALITY $origname $image`;
	}
	else
	{
	    print "Skipping image $image\n";
	}
    }
}
else
{
    print "Usage: rotate_images.pl [OPTIONS] IMAGEFILES (in jpeg format)\n\n";
    print "Available options:\n";
    print "-a degrees     the amount to rotate (clockwise, default $AMOUNT)\n"; 
    print "-q quality     the output jpeg quality (default ${QUALITY}%)\n"; 
    exit(1);
}


